diff src/editfns.c @ 72751:9128a4531448

(Fsystem_name): Mention "host" in the doc string. (syms_of_editfns) <system-name>: Likewise.
author Eli Zaretskii <eliz@gnu.org>
date Sat, 09 Sep 2006 10:50:03 +0000
parents d8f99fba05ca
children 861a71881b6a
line wrap: on
line diff
--- a/src/editfns.c	Sat Sep 09 10:43:49 2006 +0000
+++ b/src/editfns.c	Sat Sep 09 10:50:03 2006 +0000
@@ -1390,7 +1390,7 @@
 }
 
 DEFUN ("system-name", Fsystem_name, Ssystem_name, 0, 0, 0,
-       doc: /* Return the name of the machine you are running on, as a string.  */)
+       doc: /* Return the host name of the machine you are running on, as a string.  */)
      ()
 {
   return Vsystem_name;
@@ -4370,7 +4370,7 @@
   Vbuffer_access_fontified_property = Qnil;
 
   DEFVAR_LISP ("system-name", &Vsystem_name,
-	       doc: /* The name of the machine Emacs is running on.  */);
+	       doc: /* The host name of the machine Emacs is running on.  */);
 
   DEFVAR_LISP ("user-full-name", &Vuser_full_name,
 	       doc: /* The full name of the user logged in.  */);